[Buildbot-commits] buildbot/buildbot/scripts logwatcher.py, 1.1, 1.2 reconfig.py, 1.2, 1.3 runner.py, 1.56, 1.57 startup.py, 1.5, 1.6

Brian Warner warner at users.sourceforge.net
Sat Sep 29 21:23:14 UTC 2007


Update of /cvsroot/buildbot/buildbot/buildbot/scripts
In directory sc8-pr-cvs3.sourceforge.net:/tmp/cvs-serv3687/buildbot/scripts

Modified Files:
	logwatcher.py reconfig.py runner.py startup.py 
Log Message:
[project @ runner: increase start/stop timeout to 10 seconds, for #68]

Original author: warner at lothar.com
Date: 2007-09-29 21:22:30+00:00

Index: reconfig.py
===================================================================
RCS file: /cvsroot/buildbot/buildbot/buildbot/scripts/reconfig.py,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- reconfig.py	25 Nov 2006 07:57:32 -0000	1.2
+++ reconfig.py	29 Sep 2007 21:23:12 -0000	1.3
@@ -20,7 +20,7 @@
         # keep reading twistd.log. Display all messages between "loading
         # configuration from ..." and "configuration update complete" or
         # "I will keep using the previous config file instead.", or until
-        # 5 seconds have elapsed.
+        # 10 seconds have elapsed.
 
         self.sent_signal = False
         lw = LogWatcher("twistd.log")

Index: startup.py
===================================================================
RCS file: /cvsroot/buildbot/buildbot/buildbot/scripts/startup.py,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -d -r1.5 -r1.6
--- startup.py	1 Aug 2007 20:31:53 -0000	1.5
+++ startup.py	29 Sep 2007 21:23:12 -0000	1.6
@@ -25,13 +25,13 @@
              ReconfigError, BuildslaveTimeoutError, BuildSlaveDetectedError
         if why.check(BuildmasterTimeoutError):
             print """
-The buildmaster took more than 5 seconds to start, so we were unable to
+The buildmaster took more than 10 seconds to start, so we were unable to
 confirm that it started correctly. Please 'tail twistd.log' and look for a
 line that says 'configuration update complete' to verify correct startup.
 """
         elif why.check(BuildslaveTimeoutError):
             print """
-The buildslave took more than 5 seconds to start and/or connect to the
+The buildslave took more than 10 seconds to start and/or connect to the
 buildmaster, so we were unable to confirm that it started and connected
 correctly. Please 'tail twistd.log' and look for a line that says 'message
 from master: attached' to verify correct startup. If you see a bunch of





More information about the Commits mailing list
Index: logwatcher.py
===================================================================
RCS file: /cvsroot/buildbot/buildbot/buildbot/scripts/logwatcher.py,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- logwatcher.py	25 Nov 2006 07:57:32 -0000	1.1
+++ logwatcher.py	29 Sep 2007 21:23:12 -0000	1.2
@@ -18,7 +18,7 @@
 
 class LogWatcher(LineOnlyReceiver):
     POLL_INTERVAL = 0.1
-    TIMEOUT_DELAY = 5.0
+    TIMEOUT_DELAY = 10.0
     delimiter = os.linesep
 
     def __init__(self, logfile):
@@ -31,7 +31,7 @@
     def start(self):
         # return a Deferred that fires when the reconfig process has
         # finished. It errbacks with TimeoutError if the finish line has not
         # been seen within 5 seconds, and with ReconfigError if the error
         # line was seen. If the logfile could not be opened, it errbacks with
         # an IOError.
         self.running = True
@@ -31,7 +31,7 @@
         # return a Deferred that fires when the reconfig process has
         # finished. It errbacks with TimeoutError if the finish line has not
-        # been seen within 5 seconds, and with ReconfigError if the error
+        # been seen within 10 seconds, and with ReconfigError if the error
         # line was seen. If the logfile could not be opened, it errbacks with
         # an IOError.

Index: runner.py
===================================================================
RCS file: /cvsroot/buildbot/buildbot/buildbot/scripts/runner.py,v
retrieving revision 1.56
retrieving revision 1.57
diff -u -d -r1.56 -r1.57
--- runner.py	25 Sep 2007 20:07:29 -0000	1.56
+++ runner.py	29 Sep 2007 21:23:12 -0000	1.57
@@ -377,8 +377,8 @@
             print "sent SIG%s to process" % signame
         return
     time.sleep(0.1)
-    while timer < 5:
-        # poll once per second until twistd.pid goes away, up to 5 seconds
+    while timer < 10:
+        # poll once per second until twistd.pid goes away, up to 10 seconds
         try:
             os.kill(pid, 0)
         except OSError:
